Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2124)

Unified Diff: cc/test/layer_tree_test.h

Issue 2337913003: Fork cc::OutputSurface into cc::CompositorFrameSink. (Closed)
Patch Set: cfsfork: android-vulkan Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/test/layer_tree_pixel_test.cc ('k') | cc/test/layer_tree_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/test/layer_tree_test.h
diff --git a/cc/test/layer_tree_test.h b/cc/test/layer_tree_test.h
index 7e85a199de8ed558ab3f66d3af098832e8a94037..be7f2d49e526999903fe6712e260b6e2da21582a 100644
--- a/cc/test/layer_tree_test.h
+++ b/cc/test/layer_tree_test.h
@@ -19,18 +19,17 @@
namespace cc {
class AnimationPlayer;
class FakeLayerTreeHostClient;
-class FakeOutputSurface;
class LayerImpl;
class LayerTreeHost;
class LayerTreeHostForTesting;
class LayerTreeHostClient;
class LayerTreeHostImpl;
-class LayerTreeTestDelegatingOutputSurfaceClient;
+class LayerTreeTestCompositorFrameSinkClient;
class ProxyImpl;
class ProxyMain;
class RemoteChannelImplForTest;
class TestContextProvider;
-class TestDelegatingOutputSurface;
+class TestCompositorFrameSink;
class TestGpuMemoryBufferManager;
class TestTaskGraphRunner;
class TestWebGraphicsContext3D;
@@ -116,7 +115,8 @@ class LayerTreeTest : public testing::Test, public TestHooks {
void DispatchCompositeImmediately();
void DispatchNextCommitWaitsForActivation();
- std::unique_ptr<OutputSurface> ReleaseOutputSurfaceOnLayerTreeHost();
+ std::unique_ptr<CompositorFrameSink>
+ ReleaseCompositorFrameSinkOnLayerTreeHost();
void SetVisibleOnLayerTreeHost(bool visible);
virtual void AfterTest() = 0;
@@ -156,19 +156,18 @@ class LayerTreeTest : public testing::Test, public TestHooks {
void DestroyLayerTreeHost();
// By default, output surface recreation is synchronous.
- void RequestNewOutputSurface() override;
+ void RequestNewCompositorFrameSink() override;
// Override this and call the base class to change what ContextProviders will
// be used (such as for pixel tests). Or override it and create your own
- // TestDelegatingOutputSurface to control how it is created.
- virtual std::unique_ptr<TestDelegatingOutputSurface>
- CreateDelegatingOutputSurface(
+ // TestCompositorFrameSink to control how it is created.
+ virtual std::unique_ptr<TestCompositorFrameSink> CreateCompositorFrameSink(
scoped_refptr<ContextProvider> compositor_context_provider,
scoped_refptr<ContextProvider> worker_context_provider);
// Override this and call the base class to change what ContextProvider will
// be used, such as to prevent sharing the context with the delegating
// OutputSurface. Or override it and create your own OutputSurface to change
// what type of OutputSurface is used, such as a real OutputSurface for pixel
// tests or a software-compositing OutputSurface.
virtual std::unique_ptr<OutputSurface> CreateDisplayOutputSurface(
scoped_refptr<ContextProvider> compositor_context_provider);
@@ -200,8 +199,8 @@ class LayerTreeTest : public testing::Test, public TestHooks {
int timeout_seconds_ = false;
- std::unique_ptr<LayerTreeTestDelegatingOutputSurfaceClient>
- delegating_output_surface_client_;
+ std::unique_ptr<LayerTreeTestCompositorFrameSinkClient>
+ compositor_frame_sink_client_;
scoped_refptr<base::SingleThreadTaskRunner> main_task_runner_;
scoped_refptr<base::SingleThreadTaskRunner> impl_task_runner_;
std::unique_ptr<base::Thread> impl_thread_;
@@ -156,19 +156,18 @@ class LayerTreeTest : public testing::Test, public TestHooks {
scoped_refptr<ContextProvider> worker_context_provider);
// Override this and call the base class to change what ContextProvider will
- // be used, such as to prevent sharing the context with the delegating
- // OutputSurface. Or override it and create your own OutputSurface to change
- // what type of OutputSurface is used, such as a real OutputSurface for pixel
- // tests or a software-compositing OutputSurface.
+ // be used, such as to prevent sharing the context with the
+ // CompositorFrameSink. Or override it and create your own OutputSurface to
+ // change what type of OutputSurface is used, such as a real OutputSurface for
+ // pixel tests or a software-compositing OutputSurface.
virtual std::unique_ptr<OutputSurface> CreateDisplayOutputSurface(
scoped_refptr<ContextProvider> compositor_context_provider);
« no previous file with comments | « cc/test/layer_tree_pixel_test.cc ('k') | cc/test/layer_tree_test.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698